const {constants, log, helpers} = require('utils-nxg-cg');
const {objectDb, extraProps} = require('./objects');
const process = require('./process');

/**
 * Method for process the data user and execute query single or batch by transactions
 * @param msg
 * @param cfg
 * @param test
 * @returns {Promise<array|object>}
 */
module.exports.processQuery = async (msg = {}, cfg = {}, test = false) => {
    try {
        const {data} = msg;

        let properties = {...objectDb};
        let extraProp = {...extraProps};

        if (!test && !data) {
            throw Error(`${constants.ERROR_PROPERTY} data`);
        }
        const valid = helpers.validProperties(properties, data, cfg);

        if (valid) {
            helpers.validProperties(extraProp, data, cfg, true);
            properties = {...properties, ...extraProp};
            if (properties.content) {
                if (!helpers.isObjectValid(properties.content))
                    throw Error(constants.ERROR_JSON_FORMAT);
                properties.content = helpers.convertToObject(properties.content);
            }
            return await process(properties);
        }
    } catch (e) {
        log.error(e);
        throw Error(e);
    }
};
